==> alfresco-data-model-23.3.13.2-sources.jar: org/alfresco/service/cmr/search/QueryParameterDefinition.java <==
/*
 * #%L
 * Alfresco Data model classes
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.service.cmr.search;

import org.alfresco.api.AlfrescoPublicApi;
import org.alfresco.service.cmr.dictionary.PropertyDefinition;
import org.alfresco.service.cmr.dictionary.DataTypeDefinition;

@AlfrescoPublicApi
public interface QueryParameterDefinition extends NamedQueryParameterDefinition
{   
    /**
     * This parameter may apply to a well known property type.
     * 
     * May be null
     * 
     * @return PropertyDefinition
     */
    public PropertyDefinition getPropertyDefinition();
    
    /**
     * Get the property type definition for this parameter.
     * It could come from the property type definition if there is one
     * 
     * Not null
     * 
     * @return DataTypeDefinition
     */
    public DataTypeDefinition getDataTypeDefinition();
    
    /**
     * Get the default value for this parameter.
     * 
     * @return String
     */
    public String getDefault();
    
    /**
     * Has this parameter got a default value?
     * 
     * @return boolean
     */
    public boolean hasDefaultValue();
}

==> alfresco-data-model-26.1.0.16-sources.jar: org/alfresco/service/cmr/search/QueryParameterDefinition.java <==
/*
 * #%L
 * Alfresco Data model classes
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.service.cmr.search;

import org.alfresco.api.AlfrescoPublicApi;
import org.alfresco.service.cmr.dictionary.DataTypeDefinition;
import org.alfresco.service.cmr.dictionary.PropertyDefinition;

@AlfrescoPublicApi
public interface QueryParameterDefinition extends NamedQueryParameterDefinition
{
    /**
     * This parameter may apply to a well known property type.
     * 
     * May be null
     * 
     * @return PropertyDefinition
     */
    public PropertyDefinition getPropertyDefinition();

    /**
     * Get the property type definition for this parameter. It could come from the property type definition if there is one
     * 
     * Not null
     * 
     * @return DataTypeDefinition
     */
    public DataTypeDefinition getDataTypeDefinition();

    /**
     * Get the default value for this parameter.
     * 
     * @return String
     */
    public String getDefault();

    /**
     * Has this parameter got a default value?
     * 
     * @return boolean
     */
    public boolean hasDefaultValue();
}
